@@ -4,9 +4,10 @@
 #' the cross-validation process is made on the given set
 #' of parameters.
 #'
-#' @param Xs A data-frame of a matrix or a list of data-frames or matrices of
-#' $n$ rows each, the number of individuals. Some rows must be missing. The
-#' different matrices can have different numbers of columns.
+#' @param Xs A matrix, if there is only one block, or a list of matrices,
+#'  if there is more than one block, of \emph{n} rows each, the number of individuals.
+#'   Some rows must be missing. The different matrices can have different numbers of columns.
+#'    The length of Xs is denoted by \emph{K}.
 #' @param Y A matrix of n rows of a vector of length n detailing the
 #' response matrix. No missing values are allowed in that matrix.
 #' @param lambda_min A real in \eqn{[0,1]}. The minimum value considered.
@@ -171,6 +172,7 @@ perf_mddsPLS <- function(Xs,Y,lambda_min=0,lambda_max=NULL,n_lambda=1,lambdas=NU
   }
 
   paras_out <- expand.grid(R,Lambdas)
+  colnames(paras_out) <- c("R","Lambdas")
   ERRORS_OUT <- matrix(NA,nrow(paras_out),q)
   if(mode=="reg"){
     FREQ_OUT <- matrix(NA,nrow(paras_out),q)
